# COST02-BP04: Implement groups and roles

## Description

Define access control cho cost management.

## Implementation Guidance

- Create roles for cost management
- Limit resource creation permissions
- Implement approval workflows
- Audit access regularly
- Document role definitions

## Risk Level

Medium - Open access leads to waste.

## Related Best Practices

- [COST02-BP03](COST02-BP03-Account-Structure.md)
- [SEC03-BP02](../../02-SEC/SEC03-IAM-Permissions-Management/SEC03-BP02-Least-Privilege.md)
